@@ -104,7 +104,8 @@ class Log_list:
 
       for auser in user_list:
 
-        if(auser[0] == -1 or not auser[0]):
+        if(auser[0] == -1):
+          # This is the name of the Default user profile
           self.combo_user.append_text(_("Default"))
           self.user_list.append(-1)
           continue
@@ -113,9 +114,12 @@ class Log_list:
                          (auser[0],) )
         oneuser = self.cur.fetchall()
 
-        self.combo_user.append_text( (oneuser[0][0] + ' ' +
-                                      oneuser[0][1] + ' ' +
-                                      oneuser[0][2]))
+        try:
+          self.combo_user.append_text( (oneuser[0][0] + ' ' +
+                                        oneuser[0][1] + ' ' +
+                                        oneuser[0][2]))
+        except:
+          continue
         # Save in a list the combo index => the user_id
         self.user_list.append(auser[0])
 
@@ -295,6 +299,7 @@ class Log_list:
     elif  alog[COLUMN_STATUS] == gcompris.bonus.COMPLETED:
         status = "Compl."
 
+    # This is the name of the Default user profile
     login = _("Default")
     self.cur.execute('SELECT login FROM users WHERE user_id=?', (alog[COLUMN_USER],))
     result = self.cur.fetchall()
