@@ -45,7 +45,8 @@ class Gcompris_hexagon:
     self.gcomprisBoard.sublevel=1
     self.gcomprisBoard.number_of_sublevel=1
     gcompris.bar_set(gcompris.BAR_LEVEL)
-    gcompris.set_default_background(self.gcomprisBoard.canvas.get_root_item())
+    gcompris.set_background(self.gcomprisBoard.canvas.get_root_item(),
+                            "hexagon/background.svgz")
     gcompris.bar_set_level(self.gcomprisBoard)
     gcompris.bar_location(-1, -1, 0.8)
     self.set_level(1)
